@@ -8,13 +8,13 @@ datgen <- function(n = 100) {
   data.frame(Time = pmin(tt, cen), status = 1 * (tt < cen),
              z1 = z1, z2 = z2, id = 1:n)
 }
-set.seed(1)
-simdata = datgen(n = 20)
+set.seed(0)
+simdata <- datgen(n = 20)
 
-X = simdata$Time
-D = simdata$status
-z1 = simdata$z1
-z2 = simdata$z2
+X <- simdata$Time
+D <- simdata$status
+z1 <- simdata$z1
+z2 <- simdata$z2
 
-result = afttest(Surv(X, D) ~ z1 + z2, testType="link", eqType="mns")
+result <- afttest(Surv(X, D) ~ z1 + z2, testType="link", eqType="mns")
 afttestplot(result)
\ No newline at end of file
